import { Request, Response } from 'express';
import { prisma } from '../../../lib/prisma';
import { Prisma } from '@prisma/client';
import { CategoryMap } from '../../../types';

export async function listArticles(req: Request, res: Response) {
  try {
    const { page = 1, category, city } = req.query;
    const perPage = 6;

    const categoryId = CategoryMap[category as string];

    // Проверка и преобразование параметров в строковые значения
    const where: Prisma.ArticleWhereInput = {
      ...(categoryId && { categoryId: categoryId }),
      ...(city && { city: city as string }),
    };

    // Рассчитываем пропуск записей для пагинации
    const skip = (Number(page) - 1) * perPage;

    // Выполняем два параллельных запроса: получение статей и подсчёт общего количества
    const [articles, total] = await Promise.all([
      prisma.article.findMany({
        where,
        include: {
          author: {
            select: {
              id: true,
              displayName: true,
              email: true,
            },
          },
        },
        skip,
        take: perPage,
        orderBy: { publishedAt: 'desc' },
      }),
      prisma.article.count({ where }),
    ]);

    // Формируем ответ
    res.json({
      articles,
      totalPages: Math.ceil(total / perPage),
      currentPage: Number(page),
    });
  } catch (error) {
    // Логируем ошибку и отправляем ответ с кодом 500
    console.error('Error during articles list:', error);
    res.status(500).json({ error: 'Server error' });
  }
}
