import express from 'express';
import { auth } from '../../middleware/auth';
import {createS3Client, getMulterS3Config, uploadToS3} from '../../services/s3Service';
import { logger } from '../../config/logger';

const router = express.Router();

// Конфигурация для подключения к S3
const BUCKET_NAME = process.env.AWS_S3_BUCKET || '';
const REGION = process.env.AWS_REGION || 'ru-central1'
const AWS_ENDPOINT = process.env.AWS_ENDPOINT || ''
const ACCESS_KEY_ID = process.env.AWS_ACCESS_KEY_ID || '';
const SECRET_ACCESS_KEY = process.env.AWS_SECRET_ACCESS_KEY || '';

// Создаем клиент S3
const s3Client = createS3Client(REGION, AWS_ENDPOINT, ACCESS_KEY_ID, SECRET_ACCESS_KEY);

// Настройка Multer
const upload = getMulterS3Config(s3Client, BUCKET_NAME);

// Роут для загрузки изображения
router.post('/upload-url', auth, upload, async (req, res): Promise<void> => {
  if (!req.file) {
    res.status(400).json({ error: 'No file uploaded' });
    return
  }

  const file = req.file as Express.MulterS3.File;
  const folder = req.body.folder as string;
  const resolutionId = req.body.resolutionId as string;
  const quality = 80;

  try {
    // Загружаем файл в S3 после оптимизации
    const fileUrl = await uploadToS3(s3Client, BUCKET_NAME, folder, file, resolutionId, quality);
    res.json({ message: 'Файл успешно загружен', fileUrl });
  } catch (error) {
    logger.error(`Ошибка загрузки файла в S3: ${file.key}`);
    console.error(error);
    res.status(500).json({ error: 'Ошибка загрузки файла в S3' });
  }
});


/*
router.get('/:id', auth, async (req, res) => {
  try {
    const { id } = req.params;
    const image = await getImage(id, BUCKET_NAME);
    res.json(image);
  } catch (error) {
    logger.error('Error fetching image:', error);
    res.status(500).json({ error: 'Failed to fetch image' });
  }
});
*/

export default router;